<?php
/**
 * Theme functions and definitions
 *
 * @package Typal2woo
 */

if ( ! function_exists( 'typal2_setup' ) ) :
function typal2_setup() {

	/**
	 * Set the content width based on the theme's design and stylesheet.
	 */
	if ( ! isset( $content_width ) ) {
		global $content_width;
		$content_width = 658; /* pixels */
	}
	/**
	 * Make theme available for translation
	 */
	load_theme_textdomain( 'typal2', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * Enable support WooCommerce
	 */
	add_theme_support( 'woocommerce' );

	/**
	 * Editor styles for the win
	 */
	add_editor_style( 'css/editor-style.css' );

	/**
	 * Enable support for Post Thumbnails on posts and pages
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
                set_post_thumbnail_size( 200, 150, true );
                add_image_size( 'typal2-medium', 800, 450, true );
	add_image_size( 'typal2-small', 75, 75, true );
                add_image_size( 'typal2-big', 1200, 800, true );

	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'typal2' ),
		'social' => __( 'Social Menu', 'typal2' ),
	) );

	/**
	 * Enable support for Post Formats
	 */
	add_theme_support( 'post-formats', array( 'image', 'video', 'audio', 'quote', 'link', 'aside', 'status', 'gallery' ) );

	/**
	 * Setup the WordPress core custom header image.
	 */
	add_theme_support( 'custom-header', apply_filters( 'typal2_custom_header_args', array(
		'default-image'          => get_template_directory_uri().'/img/top.png',
                                'header-text'            => true,
		'default-text-color'     => 'a86dad',
		'width'                  => 1020,
		'height'                 => 450,
		'flex-height'            => true,
                                'flex-width'    => true, 
	) ) );

	/**
	 * Setup the WordPress core custom background feature.
	 */
	add_theme_support( 'custom-background', apply_filters( 'typal2_custom_background_args', array(
		'default-color' => 'fff',
		'default-image' => get_template_directory_uri().'/img/bg.gif',
	) ) );
}
endif; // typal2_setup
add_action( 'after_setup_theme', 'typal2_setup' );

/**
 * Register widgetized area and update sidebar with default widgets
 */
function typal2_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar Posts', 'typal2' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Sidebar Pages', 'typal2' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
       register_sidebar(array(
            'name' => __('Home Bottom', 'typal2'),
            'description' => __('Located at the bottom of the Home page', 'typal2'),
            'id' => 'home-bottom',
            'before_title' => '<p class="mini-title">',
            'after_title' => '</p>',
            'before_widget' => '<div class="col">',
            'after_widget' => '</div>'
        ));
       register_sidebar(array(
            'name' => __('Footer1', 'typal2'),
            'description' => __('Located in the footer left.', 'typal2'),
            'id' => 'footer1',
            'before_title' => '<h5>',
            'after_title' => '</h5>',
            'before_widget' => '<div class="widget">',
            'after_widget' => '</div>'
        ));
       register_sidebar(array(
            'name' => __('Footer2', 'typal2'),
            'description' => __('Located in the footer center.', 'typal2'),
            'id' => 'footer2',
            'before_title' => '<h5>',
            'after_title' => '</h5>',
            'before_widget' => '<div class="widget">',
            'after_widget' => '</div>'
        ));
       register_sidebar(array(
            'name' => __('Footer3', 'typal2'),
            'description' => __('Located in the footer right.', 'typal2'),
            'id' => 'footer3',
            'before_title' => '<h5>',
            'after_title' => '</h5>',
            'before_widget' => '<div class="widget">',
            'after_widget' => '</div>'
        ));
}
add_action( 'widgets_init', 'typal2_widgets_init' );

/**
 * Footer credits.
 */
function typal2_txt_credits() {
	$text = sprintf( __( 'Powered by %s', 'typal2' ), '<a href="http://wordpress.org/">WordPress</a>' );
	$text .= '<span class="sep"> &middot; </span>';
	$text .= sprintf( __( 'Theme by %s', 'typal2' ), '<a href="http://themes.makewp.ru/en/">MakeWP</a>' );
	echo apply_filters( 'typal2_txt_credits', $text );
}
add_action( 'typal2_credits', 'typal2_txt_credits' );

/**
 *=Enqueue scripts
 */
function typal2_scripts() {
                wp_enqueue_style( 'typal2-style', get_stylesheet_uri() );

	wp_enqueue_script( 'typal2-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '13072014', true );

                wp_enqueue_style( 'typal2-googlefonts', '//fonts.googleapis.com/css?family=Open+Sans:300italic,400italic,700italic,400,600,700,300' );

	wp_enqueue_style( 'genericons', get_template_directory_uri() . '/genericons/genericons.css?v=1406' );//Genericons

	wp_enqueue_style( 'awesome', get_template_directory_uri() . '/font-awesome/css/font-awesome.min.css?v=1307' );//Awesome

	wp_enqueue_script( 'typal2-fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', array( 'jquery' ), '1.1', true );

	wp_enqueue_script( 'flexslider-script', get_template_directory_uri() . '/js/jquery.flexslider-min.js', array( 'jquery' ), '13072014', true );

	wp_enqueue_style( 'flexslider-style', get_template_directory_uri() . '/css/flexslider.css?v=1307' );

	wp_enqueue_script( 'typal2-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '13072014', true );

	wp_enqueue_script( 'typal2-main', get_template_directory_uri() . '/js/main.js', array( 'jquery' ), '1.0', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'typal2-keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '13072014' );
	}
}
add_action( 'wp_enqueue_scripts', 'typal2_scripts' );

/**
 * Shorten excerpt length
 */
function typal2_excerpt_length($length) {
	if ( is_sticky() ) {
		$length = 48;
	} elseif ( is_home() ) {
		$length = 20;
	} else {
		$length = 40;
	}
	return $length;
}
add_filter('excerpt_length', 'typal2_excerpt_length', 999);

/**
 * Replace [...] in excerpts with something new
 */
function typal2_excerpt_more($more) {
	return '&hellip;';
}
add_filter('excerpt_more', 'typal2_excerpt_more');

/**
 * Breadcrumbs
 */
require get_template_directory() . '/inc/breadcrumbs.php';

/**
 * Custom Pagination
 */
require get_template_directory() . '/inc/pagination.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Custom gallery layout
 */
require( get_template_directory() . '/inc/gallery-layout.php');

/**
 *=Options Theme admin
 */
require(get_template_directory() . '/theme-options/theme-admin.php');

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/typal2-customizer.php';

/**
 *===============ADD FUNCTIONS============*
 */

/**
 * Widget Post Formats Sidebar Display
 */
require get_template_directory() . '/inc/format-aside-widget.php';
require get_template_directory() . '/inc/format-quote-widget.php';
require get_template_directory() . '/inc/format-gallery-widget.php';
require get_template_directory() . '/inc/format-video-widget.php';

/**
 * Add metabox Excerpt for Page.
 */
function typal2_add_excerpt_to_pages() {
	add_post_type_support( 'page', 'excerpt' );
}
add_action('init', 'typal2_add_excerpt_to_pages');

/**
 * ===============Ready WooPlugins===========*
 */
require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
//plugin activate?

/*=WooTestimonials Plugin*/

if (is_plugin_active('testimonials-by-woothemes/woothemes-testimonials.php')) {

	function typal2_wootestimonials_css() {
		wp_enqueue_style( 'wootestimonials-custom-style', get_template_directory_uri() . '/css/wootestimonial.css' );
	}
add_action( 'wp_enqueue_scripts', 'typal2_wootestimonials_css' );

} // wootestimonials is_plugin_active

/*=WooCommerce Plugin*/

if (is_plugin_active('woocommerce/woocommerce.php')) {

	function typal2_woocommerce_css() {
		wp_enqueue_style( 'woocommerce-custom-style', get_template_directory_uri() . '/css/woocommerce.css' );
	}
add_action( 'wp_enqueue_scripts', 'typal2_woocommerce_css' );

	function woocommerce_widgets_init() {
		register_sidebar(array(
		'name' => __('Store Sidebar', 'typal2'),
		'description' => __('Located in the sidebar woocommerce page.', 'typal2'),
		'id' => 'store',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>'
		));
	}
add_action( 'widgets_init', 'woocommerce_widgets_init' );

} // woocommerce is_plugin_active